(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     28259,        589]
NotebookOptionsPosition[     28433,        575]
NotebookOutlinePosition[     29153,        600]
CellTagsIndexPosition[     29110,        597]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Reduction of a distributed loading\n",
 StyleBox["Katherine Yang, Baoxing Xu  \nUniversity of Virginia, 09-19-2017",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "\nA body subjected to loading distributed over its surface can be \
simplified to one point force, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]]],
 ".The magnitude of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]]],
 " is equvalent to the sum of all the forces in the system. Integration is \
used to determine the differential area dA under the loading curve for the \
entire length L. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]]],
 " = \[Integral] w(x) dx from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    SubscriptBox["x", 
     RowBox[{"1", " "}]]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"to", " ", 
    SubscriptBox["x", "2"]}], TraditionalForm]]],
 "]. \nThe location x-bar of the line of action of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "R"], TraditionalForm]]],
 " can be determined by equating the moments of the force resultant and the \
parallel force distribution about point O (the y axis).\nTherefore, x-bar = \
\[Integral] xw(x) dx / \[Integral]w(x) dx from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    SubscriptBox["x", 
     RowBox[{"1", " "}]]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"to", " ", 
    SubscriptBox["x", "2"]}], TraditionalForm]]],
 "]. This coordinate locates the geometric center or centroid of the area \
under the distributed load. "
}], "Text"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`a$$ = 0, $CellContext`b$$ = 
    0, $CellContext`c$$ = 0, $CellContext`l$$ = 0, $CellContext`opa1$$ = 
    0, $CellContext`opa9$$ = 1, $CellContext`x1$$ = 0, $CellContext`x11$$ = 3,
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`opa1$$], 0, 
       Row[{"Coordinate visibility", 
         Spacer[20]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa9$$], 1, 
       Row[{"Resultant Force", 
         Spacer[31]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`l$$], 0, 
       Row[{"Hinge position (m)", 
         Spacer[2]}]}, 0, 3}, {{
       Hold[$CellContext`a$$], 0, 
       Row[{"a", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`b$$], 0, 
       Row[{"b", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`c$$], 0, 
       Row[{"c", 
         Spacer[5]}]}, -3, 3}, {{
       Hold[$CellContext`x1$$], 0, 
       Row[{"\!\(\*SubscriptBox[\(x\), \(1\)]\)", 
         Spacer[5]}]}, 0, 3}, {{
       Hold[$CellContext`x11$$], 3, 
       Row[{"\!\(\*SubscriptBox[\(x\), \(2\)]\)", 
         Spacer[5]}]}, 0, 3}, {
      Hold[
       Grid[{{
          Manipulate`Place[1]}, {
          Manipulate`Place[2]}, {
          Manipulate`Place[3]}, {
          Row[{
            Text[
             Style[
             "Input Distributive Load: f(x)= \!\(\*SuperscriptBox[\(ax\), \(2\
\)]\)+bx+c", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[4]}, {
          Manipulate`Place[5]}, {
          Manipulate`Place[6]}, {
          Row[{
            Text[
             Style[
             "Range of Distributive Load, from \!\(\*SubscriptBox[\(x\), \
\(1\)]\) to \!\(\*SubscriptBox[\(x\), \(2\)]\)", 12]]}, Alignment -> Left]}, {
          Manipulate`Place[7]}, {
          Manipulate`Place[8]}}, Alignment -> Left, 
        Spacings -> {Automatic, 1.5}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {603., {329., 338.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`opa1$12928$$ = False, $CellContext`opa9$12929$$ = 
    False, $CellContext`l$12930$$ = 0, $CellContext`a$12931$$ = 
    0, $CellContext`b$12932$$ = 0, $CellContext`c$12933$$ = 
    0, $CellContext`x1$12934$$ = 0, $CellContext`x11$12935$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`a$$ = 0, $CellContext`b$$ = 
        0, $CellContext`c$$ = 0, $CellContext`l$$ = 0, $CellContext`opa1$$ = 
        0, $CellContext`opa9$$ = 1, $CellContext`x1$$ = 0, $CellContext`x11$$ = 
        3}, "ControllerVariables" :> {
        Hold[$CellContext`opa1$$, $CellContext`opa1$12928$$, False], 
        Hold[$CellContext`opa9$$, $CellContext`opa9$12929$$, False], 
        Hold[$CellContext`l$$, $CellContext`l$12930$$, 0], 
        Hold[$CellContext`a$$, $CellContext`a$12931$$, 0], 
        Hold[$CellContext`b$$, $CellContext`b$12932$$, 0], 
        Hold[$CellContext`c$$, $CellContext`c$12933$$, 0], 
        Hold[$CellContext`x1$$, $CellContext`x1$12934$$, 0], 
        Hold[$CellContext`x11$$, $CellContext`x11$12935$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`size$, $CellContext`l0$, $CellContext`l1$, \
$CellContext`l2$, $CellContext`w$, $CellContext`\[Theta]$, $CellContext`\
\[Alpha]$, $CellContext`\[Beta]$, $CellContext`\[Gamma]$, $CellContext`t$, \
$CellContext`ts$, $CellContext`te$, $CellContext`list$, \
$CellContext`location$, $CellContext`delta$, $CellContext`dwf0$, \
$CellContext`dwf1$, $CellContext`dwf2$, $CellContext`dwf3$, \
$CellContext`dwf4$, $CellContext`dwf5$, $CellContext`dwf6$, \
$CellContext`dwf7$, $CellContext`dwf8$, $CellContext`dwf9$, \
$CellContext`dw1$, $CellContext`dw2$, $CellContext`an$, $CellContext`opa3$, \
$CellContext`opa8$, $CellContext`opa5$, $CellContext`opa7$, $CellContext`m$, \
$CellContext`ma$, $CellContext`ma2$, $CellContext`label$, $CellContext`x2$, \
$CellContext`x3$, $CellContext`x4$, $CellContext`x5$, $CellContext`y1$, \
$CellContext`y2$, $CellContext`y3$, $CellContext`y4$, $CellContext`y5$, \
$CellContext`i$, $CellContext`p1$, $CellContext`p2$}, $CellContext`\[Alpha]$ = \
($CellContext`\[Alpha]d/180) Pi; $CellContext`l0$ = 3; $CellContext`m$ = 
         3; $CellContext`R = 
         Integrate[$CellContext`a$$ $CellContext`x^2 + $CellContext`b$$ \
$CellContext`x + $CellContext`c$$, {$CellContext`x, $CellContext`x11$$, \
$CellContext`x1$$}]; $CellContext`location$ = 
         Integrate[$CellContext`x ($CellContext`a$$ $CellContext`x^2 + \
$CellContext`b$$ $CellContext`x + $CellContext`c$$), {$CellContext`x, \
$CellContext`x11$$, $CellContext`x1$$}]; $CellContext`ld = 
         If[$CellContext`R == 0, 
           0, $CellContext`location$/$CellContext`R]; $CellContext`l2$ = \
$CellContext`ld - $CellContext`l$$; $CellContext`w$ = 
         0.01 $CellContext`m$; $CellContext`size$ = 3.5; $CellContext`ts$ = 
         0; $CellContext`te$ = 15; $CellContext`\[Gamma]$ = 
         NDSolveValue[{(((1/
                 12) $CellContext`m$) $CellContext`l0$^2 + $CellContext`m$ ((
                   1/2) $CellContext`l0$ - $CellContext`l$$)^2) D[
               $CellContext`\[Theta]$[$CellContext`t$], {$CellContext`t$, 
                2}] == $CellContext`R $CellContext`l2$, \
$CellContext`\[Theta]$[0] == 0, Derivative[1][$CellContext`\[Theta]$][0] == 
            0}, $CellContext`\[Theta]$, {$CellContext`t$, $CellContext`ts$, \
$CellContext`te$}]; $CellContext`ma$ = 
         If[0 != $CellContext`R $CellContext`l2$, ((($CellContext`R \
$CellContext`l2$)/(3 $CellContext`l0$)) 2) Pi, 0]; $CellContext`ma2$ = 
         If[
          0 != $CellContext`R $CellContext`l2$, $CellContext`R \
$CellContext`l2$, 0]; $CellContext`opa3$ = 
         If[$CellContext`R != 0, 1, 0]; $CellContext`opa5$ = 
         If[$CellContext`\[Gamma]$[$CellContext`t$] != 0, 1, 
           0]; $CellContext`opa7$ = 
         If[$CellContext`ma$ != 0, 1, 0]; $CellContext`opa8$ = 
         If[$CellContext`Y != {0}, 1, 
           0]; $CellContext`delta$ = ($CellContext`x11$$ - $CellContext`x1$$)/
          10; $CellContext`X = 
         Table[$CellContext`x1$$ + $CellContext`i$ $CellContext`delta$, \
{$CellContext`i$, 0, 
            10}]; $CellContext`Y = $CellContext`a$$ $CellContext`X^2 + \
$CellContext`b$$ $CellContext`X + $CellContext`c$$; $CellContext`list$ = 
         Thread[{$CellContext`X, $CellContext`Y}]; $CellContext`dwf0$ = {
           Opacity[$CellContext`opa1$$], 
           Dashing[{}], 
           Thickness[0.001], 
           Arrowheads[0.02], 
           Arrow[{{-$CellContext`size$, 0}, {$CellContext`size$, 0}}], 
           Arrow[{{0, -$CellContext`size$}, {0, $CellContext`size$}}], 
           Text[
           "\!\(\*\nStyleBox[\"x\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {
            0.95 $CellContext`size$, (-0.05) $CellContext`size$}], 
           Text[
           "\!\(\*\nStyleBox[\"y\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {(-0.05) $CellContext`size$, 
             0.95 $CellContext`size$}]}; $CellContext`dwf1$ = {
           
           Rectangle[{
            0, (((-1)/2) 2.5) $CellContext`w$}, {$CellContext`l0$, ((1/2) 
              2.5) $CellContext`w$}]}; $CellContext`dwf3$ = {
           Opacity[$CellContext`opa9$$], Red, 
           Thickness[0.005], 
           Arrowheads[0.04], 
           Arrow[{{$CellContext`l$$ + $CellContext`l2$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + $CellContext`R Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ 
               Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - $CellContext`R Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
$CellContext`l2$ Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ 
              Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           Text[
           "\!\(\*SubscriptBox[\n StyleBox[\"F\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"], \"R\"]\)", {$CellContext`l$$ + $CellContext`l2$ Cos[
                $CellContext`\[Gamma]$[$CellContext`t$]] + 0.5 Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], $CellContext`l2$ Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]] - 0.5 Cos[
               $CellContext`\[Gamma]$[$CellContext`t$]]}]}; \
$CellContext`dwf5$ = {
           Opacity[$CellContext`opa5$], Dashed, 
           Line[{{0, 0}, {$CellContext`l0$, 0}}]}; $CellContext`dwf6$ = {Red, 
           PointSize[0.02], 
           Point[{$CellContext`l$$, 0}], 
           
           Triangle[{{$CellContext`l$$, 0}, {$CellContext`l$$ - 0.3 
              Sin[Pi/6], (-0.3) Cos[Pi/6]}, {$CellContext`l$$ + 
              0.3 Sin[Pi/6], (-0.3) Cos[Pi/6]}}], 
           Thickness[0.005], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ + 0.3 Sin[Pi/6] + 0.1, (-0.3) 
              Cos[Pi/6]}}], 
           Thickness[0.001], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6], (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.1, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.1 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.2, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.2 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.3, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.3 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 Sin[Pi/3]}}], 
           
           Line[{{$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.4, (-0.3) 
              Cos[Pi/6]}, {$CellContext`l$$ - 0.3 Sin[Pi/6] + 0.4 - 0.1 
              Cos[Pi/3], (-0.3) Cos[Pi/6] - 0.1 
              Sin[Pi/3]}}]}; $CellContext`dwf7$ = {
           Opacity[$CellContext`opa7$], 
           Thickness[0.005], 
           Arrowheads[0.03], 
           Arrow[
            Map[N[
              Table[{
                  Cos[$CellContext`k], 
                  Sin[$CellContext`k]} Part[#, 2] + 
               Part[#, 1], {$CellContext`k, 
                Part[#, 3], 
                Part[#, 4], (Part[#, 4] - Part[#, 3])/
                Part[#, 5]}]]& , {{{$CellContext`l$$, -1}, 0.3, 
               0, $CellContext`ma$, 100}}]], 
           Text[
           "\!\(\*\nStyleBox[\"M\",\nFontWeight->\"Bold\",\n\
FontSlant->\"Italic\"]\)", {$CellContext`l$$, -1}]}; $CellContext`dwf8$ = {
           Opacity[$CellContext`opa8$], Dashed, 
           
           Line[{{$CellContext`l$$ + (
                Part[$CellContext`X, 1] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 1] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 1] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 1] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 2] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 2] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 2] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 2] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 3] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 3] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 3] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 3] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 4] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 4] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 4] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 4] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 5] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 5] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 5] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 5] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 6] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 6] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 6] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 6] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 7] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 7] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 7] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 7] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 8] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 8] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 8] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 8] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 9] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 9] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 9] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 9] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 10] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 10] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 10] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 10] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 11] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 11] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 11] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 11] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}}]}; \
$CellContext`dwf9$ = {
           Opacity[$CellContext`opa8$], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 1] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 1] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 1] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 1] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 1] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 1] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 3] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 3] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 3] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 3] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 3] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 3] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 5] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 5] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 5] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 5] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 5] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 5] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 7] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 7] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 7] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 7] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 7] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 7] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 9] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 9] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 9] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 9] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 9] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 9] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}], 
           
           Arrow[{{$CellContext`l$$ + (
                Part[$CellContext`X, 11] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]] - 
              Part[$CellContext`Y, 11] Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]], (
                Part[$CellContext`X, 11] - $CellContext`l$$) Sin[
                 $CellContext`\[Gamma]$[$CellContext`t$]] + 
              Part[$CellContext`Y, 11] Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]]}, {$CellContext`l$$ + \
(Part[$CellContext`X, 11] - $CellContext`l$$) Cos[
                 $CellContext`\[Gamma]$[$CellContext`t$]], (
               Part[$CellContext`X, 11] - $CellContext`l$$) Sin[
                $CellContext`\[Gamma]$[$CellContext`t$]]}}]}; \
$CellContext`label$ = Text[
           Style[
            Row[{"t  = ", 
              NumberForm[$CellContext`t$, {4, 2}], 
              Spacer[10], 
              "\!\(\*\nStyleBox[\"M\",\nFontSlant->\"Italic\"]\)  = ", 
              N[$CellContext`ma2$, 2], 
              Spacer[10], "\!\(\*SubscriptBox[\(F\), \(R\)]\) = ", 
              N[$CellContext`R, 2], 
              Spacer[10], "x-bar = ", 
              N[$CellContext`ld, 2]}], 12]]; $CellContext`dw1$ = Graphics[{
            Rotate[$CellContext`dwf1$, 
             $CellContext`\[Gamma]$[$CellContext`t$], {$CellContext`l$$, 
              0}], $CellContext`dwf0$, $CellContext`dwf3$, \
$CellContext`dwf5$, $CellContext`dwf6$, $CellContext`dwf7$, \
$CellContext`dwf8$, $CellContext`dwf9$}, PlotRange -> $CellContext`size$, 
           ImageSize -> 350, PlotLabel -> 
           Pane[$CellContext`label$, Alignment -> {Center, Top}, ImageSize -> 
             300], Frame -> True]; $CellContext`an$ = Animate[
           Evaluate[
            
            ReplaceAll[$CellContext`dw1$, {$CellContext`t$ -> \
$CellContext`time}]], {{$CellContext`time, $CellContext`ts$, 
             "t"}, $CellContext`ts$, $CellContext`te$}, 
           DefaultDuration -> $CellContext`te$, AnimationRunning -> False, 
           ImageMargins -> Small]; $CellContext`an$], 
      "Specifications" :> {{{$CellContext`opa1$$, 0, 
          Row[{"Coordinate visibility", 
            Spacer[20]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 1}, {{$CellContext`opa9$$, 1, 
          Row[{"Resultant Force", 
            Spacer[31]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> 
         RadioButton, ControlPlacement -> 2}, {{$CellContext`l$$, 0, 
          Row[{"Hinge position (m)", 
            Spacer[2]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 3}, {{$CellContext`a$$, 0, 
          Row[{"a", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 4}, {{$CellContext`b$$, 0, 
          Row[{"b", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 5}, {{$CellContext`c$$, 0, 
          Row[{"c", 
            Spacer[5]}]}, -3, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 6}, {{$CellContext`x1$$, 0, 
          Row[{"\!\(\*SubscriptBox[\(x\), \(1\)]\)", 
            Spacer[5]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 7}, {{$CellContext`x11$$, 3, 
          Row[{"\!\(\*SubscriptBox[\(x\), \(2\)]\)", 
            Spacer[5]}]}, 0, 3, ImageSize -> Small, Appearance -> "Labeled", 
         ControlPlacement -> 8}, 
        Grid[{{
           Manipulate`Place[1]}, {
           Manipulate`Place[2]}, {
           Manipulate`Place[3]}, {
           Row[{
             Text[
              Style[
              "Input Distributive Load: f(x)= \!\(\*SuperscriptBox[\(ax\), \
\(2\)]\)+bx+c", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[4]}, {
           Manipulate`Place[5]}, {
           Manipulate`Place[6]}, {
           Row[{
             Text[
              Style[
              "Range of Distributive Load, from \!\(\*SubscriptBox[\(x\), \(1\
\)]\) to \!\(\*SubscriptBox[\(x\), \(2\)]\)", 12]]}, Alignment -> Left]}, {
           Manipulate`Place[7]}, {
           Manipulate`Place[8]}}, Alignment -> Left, 
         Spacings -> {Automatic, 1.5}]}, 
      "Options" :> {ControlPlacement -> Left}, "DefaultOptions" :> {}],
     ImageSizeCache->{1077., {374., 383.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1920, 997},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]]}, WindowSize -> {775, 872}, 
  WindowMargins -> {{175, Automatic}, {47, Automatic}}, FrontEndVersion -> 
  "11.0 for Microsoft Windows (64-bit) (July 28, 2016)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 214, 6, 230, "Title"],
Cell[1703, 43, 1445, 44, 167, "Text"],
Cell[3151, 89, 25266, 483, 781, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature Rx0RLoeTqxKKVDwvgTg5hc5F *)
